@@ -58,7 +58,7 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
-#define SIZEOF___INT128 16
+#define SIZEOF___INT128 0
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -66,7 +66,7 @@
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
 #define PACKED_STRUCT(x) x __attribute__((packed))
-#define PACKED_STRUCT_UNALIGNED(x) x
+#define USE_UNALIGNED_MEMBER_ACCESS 1
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
@@ -122,19 +122,16 @@
 #define PUREFUNC(x) __attribute__ ((__pure__)) x
 #define NORETURN(x) __attribute__ ((__noreturn__)) x
 #define DEPRECATED(x) __attribute__ ((__deprecated__)) x
-#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
-#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
+#define DEPRECATED_TYPE(mesg,x) __attribute__ ((__deprecated__ mesg)) x
 #define NOINLINE(x) __attribute__ ((__noinline__)) x
 #define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
 #define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
 #define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
 #define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
-#define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
-#define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define ENUM_OVER_INT 1
@@ -184,12 +181,6 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
-#define HAVE_INT128_T 1
-#define int128_t __int128
-#define SIZEOF_INT128_T SIZEOF___INT128
-#define HAVE_UINT128_T 1
-#define uint128_t unsigned __int128
-#define SIZEOF_UINT128_T SIZEOF___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -247,7 +238,9 @@
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
 #define HAVE_FDATASYNC 1
+#define HAVE_FDOPENDIR 1
 #define HAVE_FMOD 1
+#define HAVE_FSTATAT 1
 #define HAVE_FSYNC 1
 #define HAVE_FTRUNCATE 1
 #define HAVE_GETCWD 1
@@ -281,11 +274,13 @@
 #define HAVE_MKFIFO 1
 #define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
+#define HAVE_OPENAT 1
 #define HAVE_PIPE2 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PPOLL 1
 #define HAVE_PREAD 1
+#define HAVE_PWRITE 1
 #define HAVE_READLINK 1
 #define HAVE_ROUND 1
 #define HAVE_SEEKDIR 1
@@ -321,9 +316,6 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
-#define HAVE_BUILTIN___BUILTIN_BSWAP16 1
-#define HAVE_BUILTIN___BUILTIN_BSWAP32 1
-#define HAVE_BUILTIN___BUILTIN_BSWAP64 1
 #define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
 #define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
@@ -333,7 +325,6 @@
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
-#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
@@ -341,10 +332,6 @@
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
 #define HAVE_DAYLIGHT 1
-#define HAVE_VAR_TIMEZONE 1
-#define TYPEOF_VAR_TIMEZONE long
-#define HAVE_TIMEZONE 1
-#define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define HAVE_SIG_T 1
@@ -358,13 +345,13 @@
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
+#define HAVE_PTHREAD_ATTR_INIT 1
 #define HAVE_PTHREAD_STACKSEG_NP 1
 #define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
 #define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SET_NAME_NP 1
-#define HAVE_PTHREAD_ATTR_INIT 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_set_name_np(pthread_self(), name)
 #define SET_ANOTHER_THREAD_NAME(thid,name) pthread_set_name_np(thid, name)
 #define UCONTEXT_IN_SIGNAL_H 1
