@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.5.") or
-    raise "ruby lib version (2.5.0) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.5.5) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.5/mips64el-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "5"
-  CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "0"
-  CONFIG["INSTALL"] = '/usr/ports/pobj/ruby-2.5.0/bin/install -c '
+  CONFIG["TEENY"] = "5"
+  CONFIG["PATCHLEVEL"] = "157"
+  CONFIG["INSTALL"] = '/home/pea/pobj/ruby-2.5.5/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)25"
@@ -146,9 +146,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/ports/pobj/ruby-2.5.0/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/ports/pobj/ruby-2.5.0/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/ports/pobj/ruby-2.5.0/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/home/pea/pobj/ruby-2.5.5/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/home/pea/pobj/ruby-2.5.5/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/home/pea/pobj/ruby-2.5.5/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -181,23 +181,23 @@ module RbConfig
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd6.3"
+  CONFIG["target_os"] = "openbsd6.5"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64el"
-  CONFIG["target"] = "mips64el-unknown-openbsd6.3"
-  CONFIG["host_os"] = "openbsd6.3"
+  CONFIG["target"] = "mips64el-unknown-openbsd6.5"
+  CONFIG["host_os"] = "openbsd6.5"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64el"
-  CONFIG["host"] = "mips64el-unknown-openbsd6.3"
+  CONFIG["host"] = "mips64el-unknown-openbsd6.5"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.3"
+  CONFIG["build_os"] = "openbsd6.5"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64el"
-  CONFIG["build"] = "mips64el-unknown-openbsd6.3"
+  CONFIG["build"] = "mips64el-unknown-openbsd6.5"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.5.0"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.5.5"
   CONFIG["HAVE_GIT"] = "no"
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
