@@ -411,19 +411,18 @@ module WEBrick
         if @request_method == "HEAD"
           # do nothing
         elsif chunked?
+          buf  = ''
           begin
-            buf  = ''
-            data = ''
-            while true
-              @body.readpartial( @buffer_size, buf ) # there is no need to clear buf?
-              data << format("%x", buf.bytesize) << CRLF
-              data << buf << CRLF
-              socket.write(data)
-              data.clear
-              @sent_size += buf.bytesize
-            end
-          rescue EOFError # do nothing
-          end
+            @body.readpartial(@buffer_size, buf)
+            size = buf.bytesize
+            data = "#{size.to_s(16)}#{CRLF}#{buf}#{CRLF}"
+            socket.write(data)
+            data.clear
+            @sent_size += size
+          rescue EOFError
+            break
+          end while true
+          buf.clear
           socket.write("0#{CRLF}#{CRLF}")
         else
           if %r{\Abytes (\d+)-(\d+)/\d+\z} =~ @header['content-range']
@@ -453,11 +452,11 @@ module WEBrick
         body ? @body.bytesize : 0
         while buf = @body[@sent_size, @buffer_size]
           break if buf.empty?
-          data = ""
-          data << format("%x", buf.bytesize) << CRLF
-          data << buf << CRLF
+          size = buf.bytesize
+          data = "#{size.to_s(16)}#{CRLF}#{buf}#{CRLF}"
+          buf.clear
           socket.write(data)
-          @sent_size += buf.bytesize
+          @sent_size += size
         end
         socket.write("0#{CRLF}#{CRLF}")
       else
@@ -473,7 +472,7 @@ module WEBrick
         # do nothing
       elsif chunked?
         @body.call(ChunkedWrapper.new(socket, self))
-        _write_data(socket, "0#{CRLF}#{CRLF}")
+        socket.write("0#{CRLF}#{CRLF}")
       else
         size = @header['content-length'].to_i
         @body.call(socket)
@@ -493,7 +492,7 @@ module WEBrick
         @resp.instance_eval {
           size = buf.bytesize
           data = "#{size.to_s(16)}#{CRLF}#{buf}#{CRLF}"
-          _write_data(socket, data)
+          socket.write(data)
           data.clear
           @sent_size += size
           size
